"use strict";
// const is = require('unist-util-is')
const visit = require('unist-util-visit');
const surfaceNewlines = require('./surface-newlines');
function rehypePluginFixCodeTokenNewlines() {
    return function transformer(tree) {
        // I'm deleting all node.position values here,
        // because modifications to the tree, which involve
        // the replacement of nodes, feel like they kind of
        // invalidate the position values. I'm not sure if
        // this is the right approach. Trying to reconstruct
        // updated position values seems a bit over-the-top...
        // But leaving in the potentially misleading position
        // values also didn't feel great
        visit(tree, (node) => delete node.position);
        // Dev part just to make sure this is running
        visit(tree, 'element', (node) => {
            // We're looking for paragraphs
            if (node.tagName !== 'p')
                return;
            // The paragraph must have children
            if (!node.children || node.children.length === 0)
                return;
            // The first child node must be plain text
            const firstChild = node.children[0];
            if (firstChild.type !== 'text')
                return;
            // The first child node must start with two characters
            const text = firstChild.value;
            if (text.length < 2)
                return;
            // These two characters must match a callout type
            const firstTwoChars = text.substr(0, 2);
            if (firstTwoChars !== '::')
                return;
            // Replace with a dev replacement node
            const replacementNode = {
                type: 'element',
                tagName: 'p',
                properties: {
                    style: 'color: red;',
                },
                children: [
                    {
                        type: 'text',
                        value: 'Hello world! This is from a rehype plugin.',
                    },
                ],
            };
            // Assign the target node all the properties of our replacement node
            Object.assign(node, replacementNode);
        });
        // Visit code elements, and ensure newlines are surfaced
        // as top-level children, rather than nested within tokens
        // as rehype-prism / refractor does by default
        visit(tree, 'element', (node) => {
            // We're looking for code elements
            // (note these are distinct from `inlineCode` elements)
            if (node.tagName !== 'code')
                return;
            console.log(JSON.stringify(node, null, 2));
            // The code element must have children
            if (!node.children || node.children.length === 0)
                return;
            console.log(JSON.stringify(node.children, null, 2));
            node.children = surfaceNewlines(node.children);
            console.log(JSON.stringify(node.children, null, 2));
        });
    };
}
module.exports = rehypePluginFixCodeTokenNewlines;
